@@ -212,7 +212,8 @@ exec %(erl)s \\
 
         old_cwd = os.getcwd()
         os.chdir(dst)
-        retcode = subprocess.call(['make', 'PYTHON=%s' % sys.executable])
+        make = self.options.get('make', 'make')
+        retcode = subprocess.call([make, 'PYTHON=%s' % sys.executable])
         if retcode != 0:
             raise Exception("building RabbitMQ failed")
         os.chdir(old_cwd)
